#
# spec file for package ModemManager
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           ModemManager
Version:        0.4
Release:        8.9.1
License:        LGPLv2.1+
Summary:        DBus interface for modem handling
Url:            http://cgit.freedesktop.org/ModemManager/ModemManager
Group:          Productivity/Networking/System
Source0:        ModemManager-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM ModemManager-fix-new-glib.patch bgo626421 vuntz@opensuse.org -- Fix build with recent glib
Patch0:         ModemManager-fix-new-glib.patch
# PATCH-FIX-UPSTREAM ModemManager-polkit-deprecated.patch bgo#628105 vuntz@opensuse.org -- Fix build with polkit >= 0.97
Patch1:         ModemManager-polkit-deprecated.patch
# PATCH-FIX-UPSTREAM mm-dismiss-spam-log.patch bnc#674331 binli@opensuse.org -- Dismiss the spam log of Huawei.
Patch2:         mm-dismiss-spam-log.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libgudev-1_0-devel
BuildRequires:  libtool
BuildRequires:  polkit-devel
BuildRequires:  ppp-devel
Requires:       hicolor-icon-theme
Recommends:     usb_modeswitch
Provides:       org.freedesktop.ModemManager
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
DBus interface for modem handling. Provides a standard abstracted API
(over DBus) to communicate with all sorts of modems (landline, GSM,
CDMA).

%prep
%setup -q
%patch0 -p1
%if 0%{?suse_version} >= 1140
%patch1 -p1
%endif
%patch2 -p1

%build
pppddir=`ls -1d %{_libdir}/pppd/2*`
test -n "$pppddir" || exit 1
%configure \
    --disable-static \
    --with-pppd-plugin-dir=$pppddir \
    --with-polkit
%__make %{?_smp_flags}

%install
%makeinstall
find %{buildroot} -type f -name "*.la" -delete -print

%clean
rm -rf %{buildroot}

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING AUTHORS README
%{_sbindir}/modem-manager
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.ModemManager.conf
%{_libdir}/ModemManager/
%{_datadir}/dbus-1/system-services/org.freedesktop.ModemManager.service
%{_datadir}/icons/hicolor/*/*/modem-manager.png
%{_datadir}/polkit-1/actions/org.freedesktop.modem-manager.policy
%dir /lib/udev
/lib/udev/rules.d/
%dir %{_libdir}/pppd/2.4.5
%{_libdir}/pppd/2.4.5/mm-test-pppd-plugin.so

%changelog
* Wed Apr 27 2011 binli@opensuse.org
- Add mm-dismiss-spam-log.patch, dismiss the spam log of Huawei.
  (bnc#674331, swampid#40503).
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Add hicolor-icon-theme BuildRequires and Requires since we need
  to have those macros defined and we install hicolor icons, so we
  need to have the theme installed.
* Wed Nov 10 2010 coolo@novell.com
- Remove zero-size files from documentation.
* Wed Nov 10 2010 coolo@novell.com
- Own parent directories.
* Fri Aug 27 2010 vuntz@opensuse.org
- Add ModemManager-polkit-deprecated.patch to fix build with a
  recent polkit (>= 0.97). This is only needed on openSUSE 11.4 and
  later.
* Mon Aug  9 2010 vuntz@opensuse.org
- Add ModemManager-fix-new-glib.patch to fix build with recent
  glib.
- Build PolicyKit support: add polkit-devel BuildRequires and pass
  - -with-polkit to configure.
- Do not add -fno-strict-aliasing to CFLAGS: this is not needed
  anymore.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.4:
  + For the full list of changes, see
    http://cgit.freedesktop.org/ModemManager/ModemManager/log/?id=0.4
  + bgo#604551: add an unlockRequired property that provides lock
    status, check modem PIN state before exporting it
  + bgo#608668: tag ChineBird PL68 ports
  + bgo#591047: only set auto registration if the modem isn't idle
  + bgo#608022: allow blacklisting various devices
  + bgo#617873: gsm: be more lenient in +CGDCONT parsing
  + rh#553199: ignore CSS on EVD0-capable modems.
  + rh#573510: assume +CPIN "READY" response indicates GSM
    capability
  + rh#579247: fix sypport check for last plugin
  + rh#569067: cdma: fix subclass registration state checking in
    error paths
  + rh#571921: cdma: prevent crash on modem removal
  + rh#587400: gsm/cdma: fix data port assignment
  + Updated translations.
* Wed May 26 2010 vuntz@opensuse.org
- Remove hal-devel BuildRequires again.
- Remove ozerocdoff Recommends: usb_modeswitch is the modern
  solution, and it's already recommended. And ozerocdoff depends on
  hal, which is bad.
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to version 0.3. No new features, but includes a lot of
  bug fixes and much broader hardware support.
* Thu Dec 10 2009 aj@suse.de
- Remove unused BuildRequires hal-devel
- Add build require on udev for directory ownership.
* Tue Aug 11 2009 tittiatcoke@gmail.com
- Update to the latest upstream:
  + Move device probing and detection to udev
  + Add plugin for Motorola C-series phones and BUSlink scwi275u
  + Add plugin for Qualcomm Gobi devices
  + Updated Ericsson 'mbm' driver
  + Better Huawei detection; don't drop BUSlink responses
  + Several other fixes
* Tue Jun 16 2009 tambet@novell.com
- Update to the latest upstream:
  + Some fixes to the public API to correctly implement the spec.
  + Implement unsolicited registration for modems that support it.
  + Implement new "Simple" interface.
  + Implement cached commands.
  + Implement 'V1 E1' parser to work with modems which refuse to
    turn their echo off.
  + Implement Nokia plugin.
  + Implement a plugin for ZTE modems.
  + Lots of minor bug fixes.
* Thu Feb 26 2009 tambet@novell.com
- Probe HSO modems, don't trust (often incorrect) HAL modem
  properties (bnc #468329).
* Fri Feb  6 2009 tambet@novell.com
- Fix dbus permissions (bnc #468384).
* Mon Jan 26 2009 tambet@novell.com
- Implement Novatel plugin (bnc #468323).
* Fri Jan 16 2009 tambet@novell.com
- Check the registration state even after unsuccessful attempt,
  some cards report error if they're already registered before
  the attempt (bnc #430673).
* Tue Jan  6 2009 tambet@novell.com
- Broaden the network device matching for HSO modems as some
  (newer?) modems have only matching grandparent between serial
  and ethernet device UDIs. Fix the Option driver to not steal
  HSO modems. (bnc #462534).
- Explicitly disable unsolicitied messages for generic GSM modems
  (bnc #462536).
- Not all serial devices have carrier detection. Add a property to
  the serial base class to turn it off and make certain Huawei
  modems turn it off (bnc #462567).
- Suggest "ozerocdoff" (part of bnc #405178).
* Wed Dec  3 2008 tambet@novell.com
- Fix the HSO modem plugin (bnc #449992).
- Provide 'org.freedesktop.ModemManager' so that NetworkManager
  could use alternative implementations.
* Mon Nov 24 2008 tambet@suse.de
- Always log which modem plugin is used.
* Tue Nov 18 2008 tambet@suse.de
- Don't require CDMA modems to implement verbose error reporting
  (+CMEE command) (bnc #430502).
- Add a Sierra Wireless plugin that waits a bit after enabling the
  radio (bnc #430673).
* Fri Nov  7 2008 tambet@suse.de
- Implement a plugin for Option devices.
- Enable/disable plugging with SIGUSR1.
- Recommend usb_modeswitch (bnc #442515).
* Fri Oct 24 2008 tambet@suse.de
- Add support for MBM modems.
- Use only one serial port for Huawei modems.
* Mon Oct 20 2008 tambet@suse.de
- Fix a segfault which occured when scanning results could not be
  parsed.
- Register a correct response parser for generic CDMA
  implementation.
* Fri Sep 19 2008 tambet@suse.de
- Make it build for openSUSE 11.0 as well.
- Update from upstream:
  + Implement smarter APN choosing.
  + Implement PIN changing and enabling/disabling.
  + Make sure the device is enabled before trying to send commands to it.
  + Disconnect modem if it's connected while disabling.
  + Fix the loadable module name checking.
  + Document DBus error codes and messages.
  + Get the monitoring device from HAL for Huawei modems.
  + Add correct message to mobile (+CMEE) errors.
  + Finish the non-verbose (V0) mode parser.
  + Reduce the amount of power used to minimum when modem is disabled.
  + Reset the CID when the modem is enabled/disabled and disconnected.
  + Specify call mode in the modem init string.
* Fri Sep 12 2008 tambet@suse.de
- Remove the patch to not require dbus-glib-0.75, factory has it.
- Update from upstream:
  + Rewrite the serial port handling.
  + Implement serial command queueing.
  + Define and implement error reporting.
  + Fix device added and removed signals.
* Sun Sep  7 2008 schwab@suse.de
- Use autoreconf -fi.
* Mon Sep  1 2008 tambet@suse.de
- Update from upstream:
  + Fix upper case inconsistency in the public API (SetApn).
  + Fix HSO modem plugin.
  + Implement reading IMEI, IMSI, manufacturer, model, and version (revision).
  + License ModemManager with GNU Lesser General Public License, version 2.1.
* Fri Aug 29 2008 tambet@suse.de
- Update from upstream to get the API redesign agreed on NetworkManager
  mailing list.
* Thu Aug 28 2008 tambet@suse.de
- Initial checkin for autobuild.
